function BINARY_COM = checkdeps(BINARY_LIST,verbosity,error_notfound)
%CHECKDEPS Check for existence of external binary files
%
%   binary_file = CHECKDEPS(binary_list) Returns the full path of the binary
%   file, i.e., CHECKDEPS('gnuplot') (may) return '/usr/bin/gnuplot'.
%   
%   If CHECKDEPS('gnuplot') returns '/usr/bin/gnuplot', then so will
%   CHECKDEPS('/usr/bin/gnuplot').
%
%   CHECKDEPS returns '' if the program is not found.
%
%   binary_list may be a character or a cell array and the output
%   binary_file will have the same structure as binary_list.
%
%   binary_file = CHECKDEPS(binary_list,verbosity);
%
%   binary_file = CHECKDEPS(binary_list,verbosity,error_notfound) Calls
%   error() if a file in binary_list is not found.
%   
%   
  
if (nargin < 2)
  verbosity = 0;
end

if iscell(BINARY_LIST)
  LIST = BINARY_LIST;
else
  LIST = cellstr(BINARY_LIST);
end

if (nargin < 3)
  error_notfound = zeros(1,length(LIST));
end

LISTo = LIST;
for i = 1:length(LIST)

  found = 0;

  I = findstr(LIST{i},'/');
  if ~isempty(I) % If directories included in name
    depstr = sprintf('%s',LIST{i});
    if (exist(depstr)==2)
      found = 1;
      BINARY_COM{i} = depstr;
      if (verbosity > 0)
	fprintf('checkdeps: Found %s.\n',LIST{i});
      end
    else
      if (verbosity > 0)
	fprintf('checkdeps: Did not find %s. Continuing search.\n', ...
		LIST{i});
      end
      if (I(end) < length(LIST{i})) % Extract binary name
	LIST{i} = LIST{i}(I(end)+1:end);
      end
    end
  end
  
  if (found == 0)

    % This will only work in Octave 2.9.X and later.
    [status,depstr] = system(sprintf('which %s',LIST{i}));

    if ischar(depstr)
      depstr = deblank(depstr);
    end
    if (~isempty(depstr)) & (status == 0)
      found = 1;
      BINARY_COM{i} = depstr;
      if (verbosity > 0)
	fprintf('checkdeps: Will use %s for %s.\n',BINARY_COM{i},LIST{i});
      end
    else
      if (verbosity > 0)
	fprintf('checkdeps: which %s did not find program.\n',LIST{i});
      end
    end
  end

  if (found == 0)
    depstr = sprintf('/bin/%s',LIST{i});  
    if (exist(depstr)==2)
      found = 1;
      BINARY_COM{i} = depstr;
      if (verbosity > 0)
	fprintf('checkdeps: Found %s in /bin.\n',LIST{i});
      end
    else
      if (verbosity > 0)      
	fprintf('checkdeps: Did not find /bin/%s. Continuing search.\n', ...
		LIST{i});
      end
    end
  end

  if (found == 0)
    depstr = sprintf('/usr/bin/%s',LIST{i});
    if (exist(depstr)==2)
      found = 1;
      BINARY_COM{i} = depstr;
      if (verbosity > 0)
	fprintf('checkdeps: Found %s in /usr/bin.\n',LIST{i});
      end
    else
      if (verbosity > 0)
	fprintf('checkdeps: Did not find /usr/bin/%s. Continuing search.\n',...
	      LIST{i});
      end
    end
  end
  
  if (found == 0)

    BINARY_COM{i} = '';

    if (error_notfound(i)==1)
      if isempty(I)
	error('checkdeps: Did not find %s in /bin or /usr/bin.\n',LIST{i});
      else
	error('checkdeps: Did not find %s, or /bin/%s, or /usr/bin/%s.\n',...
		LIST{i},LISTo{i},LIST{i});      
      end
    else
      if isempty(I)
	warning('checkdeps: Did not find %s in /bin or /usr/bin.\n',LIST{i});
      else
	warning('checkdeps: Did not find %s, /bin/%s, or /usr/bin/%s.\n',...
		LISTo{i},LIST{i},LIST{i});      
      end
    end
  
  end


end

if ~iscell(BINARY_LIST) & (size(BINARY_LIST,1)==1)
  tmp = BINARY_COM; clear BINARY_COM;
  BINARY_COM = tmp{1};
end
  